@@ -48,9 +48,15 @@ XMLPUBFUN xmlURIPtr XMLCALL
 		xmlCreateURI		(void);
 XMLPUBFUN xmlChar * XMLCALL	
 		xmlBuildURI		(const xmlChar *URI,
-	                        	 const xmlChar *base);
+	                         	 const xmlChar *base);
+XMLPUBFUN xmlChar * XMLCALL	
+		xmlBuildRelativeURI	(const xmlChar *URI,
+	                         	 const xmlChar *base);
 XMLPUBFUN xmlURIPtr XMLCALL	
 		xmlParseURI		(const char *str);
+XMLPUBFUN xmlURIPtr XMLCALL	
+		xmlParseURIRaw		(const char *str,
+					 int raw);
 XMLPUBFUN int XMLCALL		
 		xmlParseURIReference	(xmlURIPtr uri,
 					 const char *str);
