@@ -21,7 +21,7 @@
 #include <direct.h>
 #endif
 
-#include <libxml/xmlwin32version.h>
+#include <libxml/xmlversion.h>
 
 #ifdef NEED_SOCKETS
 #include <wsockcompat.h>
@@ -30,7 +30,7 @@
 #define HAVE_ISINF
 #define HAVE_ISNAN
 #include <math.h>
-#ifdef _MSC_VER
+#if defined(_MSC_VER) || defined(__BORLANDC__)
 /* MS C-runtime has functions which can be used in order to determine if
    a given floating-point variable contains NaN, (+-)INF. These are 
    preferred, because floating-point technology is considered propriatary
@@ -48,6 +48,7 @@
 #define isnan(d) (_isnan(d))
 #endif
 #else /* _MSC_VER */
+#ifndef isinf
 static int isinf (double d) {
     int expon = 0;
     double val = frexp (d, &expon);
@@ -63,6 +64,8 @@ static int isinf (double d) {
         return 0;
     }
 }
+#endif
+#ifndef isnan
 static int isnan (double d) {
     int expon = 0;
     double val = frexp (d, &expon);
@@ -78,32 +81,33 @@ static int isnan (double d) {
         return 0;
     }
 }
+#endif
 #endif /* _MSC_VER */
 
-#ifdef _MSC_VER
-/* We don't use trio when compiling under MSVC. This is not because trio
-   is bad, but because MSVC has no easy way to conditionally include a .c
-   file in the project. In order to enable trio usage, we would have to compile
-   all trio functionality into the executable, even if we don't use it.
-   Since MS C-runtime has all required functions, trio is not necessary. */
-#ifdef WITH_TRIO
-#undef WITH_TRIO
-#endif /* WITH_TRIO */
-#ifndef WITHOUT_TRIO
-#define WITHOUT_TRIO
-#endif /* WITHOUT_TRIO */
-/* Microsoft's C runtime names all non-ANSI functions with a leading
-   underscore. Since functionality is still the same, they can be used. */
+#if defined(_MSC_VER)
+#define mkdir(p,m) _mkdir(p)
 #define snprintf _snprintf
-#define vsnprintf _vsnprintf
-#endif /* _MSC_VER */
+#define vsnprintf(b,c,f,a) _vsnprintf(b,c,f,a)
+#elif defined(__MINGW32__)
+#define mkdir(p,m) _mkdir(p)
+#endif
 
-/* Define this if you want to use Windows native thread implementation.
-   Undefine it if you wish to use another, pthreads for example. Note
-   that this alone does not enable threads, just specifies the
-   threading model. Threading support is activated in xmlversion.h by
-   defining LIBXML_THREAD_ENABLE. */
+/* Threading API to use should be specified here for compatibility reasons.
+   This is however best specified on the compiler's command-line. */
+#if defined(LIBXML_THREAD_ENABLED)
+#if !defined(HAVE_PTHREAD_H) && !defined(HAVE_WIN32_THREADS)
 #define HAVE_WIN32_THREADS
+#endif
+#endif
+
+/* Some third-party libraries far from our control assume the following
+   is defined, which it is not if we don't include windows.h. */
+#if !defined(FALSE)
+#define FALSE 0
+#endif
+#if !defined(TRUE)
+#define TRUE (!(FALSE))
+#endif
 
 #endif /* __LIBXML_WIN32_CONFIG__ */
 
